#!/bin/sh
# kujob.sh - Kill all processes owned by a user
# Arguments - User's login name 

# Must be root
[ $UID -eq 0 ] || usage root

# Were we called properly?
getopts ":u:" OPT || usage syntax
[ "$OPT" = ":" ] && usage arg

# Does the user exist?
UNAME=$OPTARG
grep $UNAME /etc/passwd &> /dev/null || usage user

# Kill the user's processes
for SIG in TERM INT HUP QUIT KILL
do
	echo "Trying SIG$SIG"
	pkill -$SIG -u $UNAME &> /dev/null
	sleep 1
	pgrep -u $UNAME &> /dev/null || exit 0
done

# Display a short usage message
function usage
{
	ERR=$1
	case $ERR in
		"root" ) echo "Only root can run this script" ;;
		"syntax" ) echo "USAGE: kujob.sh -u UNAME" ;;
		"arg" ) echo "-u requires user name" ;;
		"user" ) echo "No such user" ;;
	esac
	exit 1
}

